summaryrefslogtreecommitdiffstats
path: root/src/core/loader/ncch.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/core/loader/ncch.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/core/loader/ncch.h b/src/core/loader/ncch.h
index 4ef95b5c6..0ebd47fd5 100644
--- a/src/core/loader/ncch.h
+++ b/src/core/loader/ncch.h
@@ -179,9 +179,9 @@ public:
/**
* Loads the Exheader and returns the system mode for this application.
* @return Optional with the kernel system mode
*/
- boost::optional<u32> LoadKernelSystemMode() override;
+ std::pair<boost::optional<u32>, ResultStatus> LoadKernelSystemMode() override;
ResultStatus ReadCode(std::vector<u8>& buffer) override;
@@ -179,9 +179,9 @@ public:
/**
* Loads the Exheader and returns the system mode for this application.
- * @return Optional with the kernel system mode
+ * @returns A pair with the optional system mode, and and the status.
*/